pub struct Permutation { /* private fields */ }Expand description
The permutation of a buffer containing vertex attribute data. The Permutation maps the layout of an input buffer’s fields to the input registers used in the picasso shader.
Implementations
Sourceimpl Permutation
impl Permutation
Sourcepub fn from_layout(layout: &[Register]) -> Result<Self, Error>
pub fn from_layout(layout: &[Register]) -> Result<Self, Error>
Construct the permutation for a buffer whos fields (in order) correspond to the provided list of input registers (as used in the picasso shader).
Example
Picasso
; Inputs (defined as aliases for convenience)
.alias inpos v0 ; fvec3
.alias innorm v1 ; fvec3
.alias intex v2 ; fvec2Rust
struct Vertex {
pos: [f32; 3],
tex: [f32; 2],
}
impl Vertex {
pub fn permutation() -> Permutation {
Permutation::from_layout(&[Register::V0, Register::V2]).unwrap()
}
}
struct Normal {
norm: [f32; 3],
}
impl Normal {
pub fn permutation() -> Permutation {
Permutation::from_layout(&[Register::V1]).unwrap()
}
}Errors
- If more than 16 attribute registers are provided (i.e.
layout.len() > 16)